@@ -20,9 +20,7 @@
 //!
 
 use bitcoin::blockdata::witness::Witness;
-use bitcoin::TxOut;
 use bitcoin::util::{sighash, taproot};
-use std::borrow::Borrow;
 use std::fmt;
 use std::str::FromStr;
 
@@ -94,7 +92,7 @@ impl KeySigPair {
 // - This does not implement ToPublicKey to avoid context dependant encoding/decoding of 33/32
 //   byte keys. This allows us to keep a single NoChecks context instead of a context for
 //   for NoChecksSchnorr/NoChecksEcdsa.
-// Long term TODO: There really should be any need for Miniscript<Pk: MiniscriptKey> struct
+// Long term TODO: There really should be not be any need for Miniscript<Pk: MiniscriptKey> struct
 // to have the Pk: MiniscriptKey bound. The bound should be on all of it's methods. That would
 // require changing Miniscript struct to three generics Miniscript<Pk, Pkh, Ctx> and bound on
 // all of the methods of Miniscript to ensure that Pkh = Pk::Hash
@@ -130,34 +128,34 @@ impl From<bitcoin::XOnlyPublicKey> for BitcoinKey {
 
 // While parsing we need to remember how to the hash was parsed so that we can
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
-enum TaggedHash160 {
+enum TypedHash160 {
     XonlyKey(hash160::Hash),
     FullKey(hash160::Hash),
 }
 
-impl fmt::Display for TaggedHash160 {
+impl fmt::Display for TypedHash160 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            TaggedHash160::FullKey(pkh) | TaggedHash160::XonlyKey(pkh) => pkh.fmt(f),
+            TypedHash160::FullKey(pkh) | TypedHash160::XonlyKey(pkh) => pkh.fmt(f),
         }
     }
 }
 
-impl TaggedHash160 {
+impl TypedHash160 {
     fn hash160(&self) -> hash160::Hash {
         match self {
-            TaggedHash160::XonlyKey(hash) | TaggedHash160::FullKey(hash) => *hash,
+            TypedHash160::XonlyKey(hash) | TypedHash160::FullKey(hash) => *hash,
         }
     }
 }
 
 impl MiniscriptKey for BitcoinKey {
-    type Hash = TaggedHash160;
+    type Hash = TypedHash160;
 
     fn to_pubkeyhash(&self) -> Self::Hash {
         match self {
-            BitcoinKey::Fullkey(pk) => TaggedHash160::FullKey(pk.to_pubkeyhash()),
-            BitcoinKey::XOnlyPublicKey(pk) => TaggedHash160::XonlyKey(pk.to_pubkeyhash()),
+            BitcoinKey::Fullkey(pk) => TypedHash160::FullKey(pk.to_pubkeyhash()),
+            BitcoinKey::XOnlyPublicKey(pk) => TypedHash160::XonlyKey(pk.to_pubkeyhash()),
         }
     }
 }
@@ -230,27 +228,27 @@ impl<'txin> Interpreter<'txin> {
     /// - Insufficient sighash information is present
     /// - sighash single without corresponding output
     // TODO: Create a good first isse to change this to error
-    pub fn verify_sig<C: secp256k1::Verification, T: Borrow<TxOut>>(
+    pub fn verify_sig<C: secp256k1::Verification>(
         &self,
         secp: &secp256k1::Secp256k1<C>,
         tx: &bitcoin::Transaction,
         input_idx: usize,
-        prevouts: &sighash::Prevouts<T>,
+        prevouts: &sighash::Prevouts<bitcoin::TxOut>,
         sig: &KeySigPair,
     ) -> bool {
-        fn get_prevout<'u, T: Borrow<TxOut>>(
-            prevouts: &'u sighash::Prevouts<'u, T>,
+        fn get_prevout<'u>(
+            prevouts: &'u sighash::Prevouts<'u, bitcoin::TxOut>,
             input_index: usize,
         ) -> Option<&'u bitcoin::TxOut> {
             match prevouts {
                 sighash::Prevouts::One(index, prevout) => {
                     if input_index == *index {
-                        Some(prevout.borrow())
+                        Some(prevout)
                     } else {
                         None
                     }
                 }
-                sighash::Prevouts::All(prevouts) => prevouts.get(input_index).map(|p| p.borrow()),
+                sighash::Prevouts::All(prevouts) => prevouts.get(input_index),
             }
         }
         let mut cache = bitcoin::util::sighash::SigHashCache::new(tx);
@@ -324,12 +322,12 @@ impl<'txin> Interpreter<'txin> {
     /// - For legacy outputs, no information about prevouts is required
     /// - For segwitv0 outputs, prevout at corresponding index with correct amount must be provided
     /// - For taproot outputs, information about all prevouts must be supplied
-    pub fn iter<'iter, C: secp256k1::Verification, T: Borrow<TxOut>>(
+    pub fn iter<'iter, C: secp256k1::Verification>(
         &'iter self,
         secp: &'iter secp256k1::Secp256k1<C>,
         tx: &'txin bitcoin::Transaction,
         input_idx: usize,
-        prevouts: &'iter sighash::Prevouts<'iter, T>, // actually a 'prevouts, but 'prevouts: 'iter
+        prevouts: &'iter sighash::Prevouts<bitcoin::TxOut>, // actually a 'prevouts, but 'prevouts: 'iter
     ) -> Iter<'txin, 'iter> {
         self.iter_custom(Box::new(move |sig| {
             self.verify_sig(secp, tx, input_idx, prevouts, sig)
@@ -391,7 +389,7 @@ impl<'txin> Interpreter<'txin> {
             inner::Inner::Script(_, inner::ScriptType::Sh) => true,
             inner::Inner::Script(_, inner::ScriptType::Wsh) => false,
             inner::Inner::Script(_, inner::ScriptType::ShWsh) => false, // lol "sorta"
-            inner::Inner::Script(_, inner::ScriptType::Tr) => true,
+            inner::Inner::Script(_, inner::ScriptType::Tr) => false,
         }
     }
 
@@ -1008,6 +1006,7 @@ fn verify_sersig<'txin>(
 #[cfg(test)]
 mod tests {
 
+    use super::inner::ToNoChecks;
     use super::*;
     use bitcoin;
     use bitcoin::hashes::{hash160, ripemd160, sha256, sha256d, Hash};
@@ -1480,6 +1479,6 @@ mod tests {
     fn no_checks_ms(ms: &str) -> Miniscript<BitcoinKey, NoChecks> {
         let elem: Miniscript<bitcoin::PublicKey, NoChecks> =
             Miniscript::from_str_insane(ms).unwrap();
-        inner::pre_taproot_to_no_checks(&elem)
+        elem.to_no_checks_ms()
     }
 }
