@@ -423,18 +423,15 @@ impl<Pk: MiniscriptKey> Policy<Pk> {
                 for sub in subs {
                     match sub {
                         Policy::Trivial | Policy::Unsatisfiable => {}
-                        Policy::Threshold(1, or_subs) => {
-                            if is_or {
-                                ret_subs.extend(or_subs);
-                            } else {
-                                ret_subs.push(Policy::Threshold(1, or_subs));
-                            }
-                        }
-                        Policy::Threshold(k, and_subs) => {
-                            if k == and_subs.len() && is_and {
-                                ret_subs.extend(and_subs)
-                            } else {
-                                ret_subs.push(Policy::Threshold(k, and_subs));
+                        Policy::Threshold(k, subs) => {
+                            match (is_and, is_or) {
+                                (true, true) => {
+                                    // means m = n = 1, thresh(1,X) type thing.
+                                    ret_subs.push(Policy::Threshold(k, subs));
+                                }
+                                (true, false) if k == subs.len() => ret_subs.extend(subs), // and case
+                                (false, true) if k == 1 => ret_subs.extend(subs), // or case
+                                _ => ret_subs.push(Policy::Threshold(k, subs)),
                             }
                         }
                         x => ret_subs.push(x),
